<?php


/*
 * Fallback Menu
 * */

function dreamy_fallback_menu(){

    echo '<span class="no-menu">' . esc_html__('Please register navigation from', 'dreamy') . ' ' .
            '<a href="' . esc_url(admin_url('nav-menus.php')).'" target="_blank">' . esc_html__('Appearance > Menus', 'dreamy') . '</a></span>';

}

/*
 * Sanitize Class
 * */

function dreamy_sanitize_class($class, $fallback = null) {

    if(is_string($class)) {
        $class = explode(' ', $class);
    }

    if(is_array($class) && count($class) > 0) {

        $class = array_map('sanitize_html_class', $class);
        return implode(' ', $class);

    } else {

        return sanitize_html_class($class, $fallback);

    }
}


/*
 * Sanitize Style
 * */

function dreamy_sanitize_style($style) {

    $allowed_html = array(
        'style' => array()
    );

    return wp_kses($style, $allowed_html);
}


/*
 * Custom comment
 * */

function dreamy_custom_comment( $comment, $args, $depth ) {
    $GLOBALS['comment'] = $comment;
    ?>

    <li class="vl-comment--item">
    <div id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>

        <?php if(get_avatar( $comment )) : ?>
        <div class="vl-comment--avatar">
            <?php echo get_avatar($comment, 50, $default = ''); ?>
        </div>
        <?php endif; ?>

        <div class="vl-comment--content">

            <div class="vl-comment--header">
                <span class="vl-comment--author h5"><?php comment_author(); ?></span>

                <span class="vl-comment--meta">
                    <a href="<?php echo esc_url(get_comment_link($comment->comment_ID)) ?>"><?php printf('%1$s', get_comment_date()); ?></a>
                    <?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => esc_html__('Reply', 'dreamy')))); ?>
                    <?php edit_comment_link(esc_html__( 'Edit', 'dreamy' ), '  ', ''); ?>
                </span>

            </div>

            <div class="vl-comment--text">

                <?php if ($comment->comment_approved == '0') : ?>
                    <p><?php esc_html_e('Your comment is awaiting moderation.', 'dreamy'); ?></p>
                <?php endif; ?>

                <?php comment_text(); ?>

            </div>

        </div>
    </div>

    <!-- </li> is added by WordPress automatically -->
    <?php
}

/*
 * Excerpt length
 * */

add_filter('excerpt_length', 'dreamy_default_excerpt_length');

function dreamy_default_excerpt_length() {
    return 60;
}


function dreamy_medium_excerpt_length() {
    return 36;
}


function dreamy_short_excerpt_length() {
    return 26;
}


function dreamy_supershort_excerpt_length() {
    return 18;
}


add_filter('excerpt_more', 'dreamy_default_excerpt_more');
function dreamy_default_excerpt_more($more) {
    return ' ...';
}


function dreamy_limit_text($content = false, $length) {

    if($content == false){
        return;
    }


    $content = preg_replace("~(?:\[/?)[^/\]]+/?\]~s", '', $content);
    $content = strip_tags($content);


    $words = explode(' ', $content, $length + 1);


    if(count($words) > $length) {
        array_pop($words);
        array_push($words, '...', '');
    }

    $content = implode(' ', $words);
    $content = '<p>' . esc_html($content) . '</p>';

    return $content;
}





/*
 * Get post taxonomy
 * */


function dreamy_post_taxonomy($post_id, $taxonomy, $delimiter = ', ', $get = 'name', $link = true) {

    $tags = wp_get_post_terms($post_id, $taxonomy);

    $list = '';

    foreach ($tags as $tag) {
        if($link) {
            $list .= '<a href="' . get_category_link($tag->term_id) . '">' . $tag->$get . '</a>' . $delimiter;
        } else {
            $list .= $tag->$get . $delimiter;
        }
    }

    return substr($list, 0, strlen($delimiter) * (-1));

}



/*
 * Post share
 * */

function dreamy_post_share_buttons($post_id) {


    $url = urlencode(get_permalink($post_id));
    $title = urlencode(get_the_title($post_id));
    $media = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), 'dreamy_fullsize');

    $output = '<div class="vl-post-share">';

    $output .= '<h6>'.esc_html__('Share:', 'dreamy').'</h6>';
    $output .= '<a class="vl-btn vl-post-share-twitter" target="_blank" href="https://twitter.com/home?status=' . $title . '+' . $url . '">Twitter</a>';
    $output .= '<a class="vl-btn vl-post-share-facebook" target="_blank" href="https://www.facebook.com/share.php?u=' . $url . '&title=' . $title . '">Facebook</a>';
    $output .= '<a class="vl-btn vl-post-share-linkedin" target="_blank" href="http://www.linkedin.com/shareArticle?mini=true&url=' . $url . '&title=' . $title . '">LinkedIn</a>';
    $output .= '<a class="vl-btn vl-post-share-pinterest" target="_blank" href="http://pinterest.com/pin/create/bookmarklet/?media=' . $media[0] . '&url=' . $url . '&is_video=false&description=' . $title . '">Pinterest</a>';
    $output .= '<a class="vl-btn vl-post-share-google-plus" target="_blank" href="https://plus.google.com/share?url=' . $url . '">Google+</a>';
    $output .= '</div>';


    return apply_filters('dreamy/post_share_buttons', $output);


}

/*
 * Pinterest share
 * */


function dreamy_pinterest_share($post_id){
    if(!get_theme_mod('pinterest_share', true)){
        return;
    }

    $url = urlencode(get_permalink($post_id));
    $title = urlencode(get_the_title($post_id));
    $media = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), 'dreamy_fullsize');

    $output = '<a class="vl-share-pinterest pinterest" target="_blank" href="http://pinterest.com/pin/create/bookmarklet/?media=' . $media[0] . '&url=' . $url . '&is_video=false&description=' . $title . '"><i class="fa fa-pinterest"></i></a>';

    return apply_filters('dreamy/pinterest_share', $output);
}


/*
 * Get post thumbnail
 * */


function dreamy_get_post_thumb($post_id, $size) {

    $thumb = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), $size);
    return $thumb['0'];

}


/*
 * Post meta
 * */

function dreamy_post_meta($before = '', $after = ''){

    global $post;

    $output = '';

    $output .= $before;

    $post_categories = get_the_category();
    $post_author_id = get_post_field( 'post_author', $post->ID );
    $userdata = get_userdata( $post_author_id );
    $userdata_url = get_author_posts_url( $post_author_id );

    $output .= '<span>'.esc_html__('By','dreamy').'</span> <a class="link" href="'.esc_url($userdata_url).'">'. esc_html($userdata->display_name) .'</a>';

    if ( !empty( $post_categories ) ) {
        $output .= ' <span>'.esc_html__('in', 'dreamy').'</span> <a class="link" href="' . esc_url(get_category_link($post_categories[0]->term_id)) . '">' . esc_html($post_categories[0]->name) . '</a>';
    }


    $output .= ' <span>'.esc_html__('on', 'dreamy').'</span> <time datetime="'.get_the_time( 'c' ).'">'.get_the_date('').'</time>';

    $output .= $after;

    return apply_filters('dreamy/post_meta', $output);


}

function dreamy_post_meta_masonry($before = '', $after = ''){

    global $post;

    $output = '';

    $output .= $before;

    $post_categories = get_the_category();

    if ( !empty( $post_categories ) ) {
        $output .= '<div><span>'.esc_html__('In', 'dreamy').'</span> <a class="link" href="' . esc_url(get_category_link($post_categories[0]->term_id)) . '">' . esc_html($post_categories[0]->name) . '</a></div>';
    }

    $output .= '<div><time datetime="'.get_the_time( 'c' ).'">'.get_the_date('').'</time></div>';

    $output .= $after;

    return apply_filters('dreamy/post_meta_masonry', $output);


}


/*
 * Post thumbnail format
 * */

function dreamy_post_thumbnail_postformat($format = '', $size = 'dreamy_fullsize'){

    global $post;

    $output = '';

    $before = '<div class="vl-post--thumbnail">';
    $after = '</div>';

    // Post video
    if($format == 'video'){

        if(has_post_thumbnail()):

            $output .= $before;

            if (class_exists('acf') && get_field('post_video_link')):

                $output .= '<div class="vl-video-lightbox"><a href="'.get_field('post_video_link').'" class="vl-video-lightbox--link is-popup"><i class="ion ion-play"></i></a>';

            endif;

            // $output .= dreamy_pinterest_share($post->ID);

            $output .= '<img src="'.dreamy_get_post_thumb($post->ID, $size).'" alt="">';

            if (class_exists('acf') && get_field('post_video_link')):

                $output .= '</div>';

            endif;

            $output .= $after;

        endif;


        // Post audio
    } elseif($format == 'audio'){


        if(has_post_thumbnail()):

            $output .= $before;

            // $output .= dreamy_pinterest_share($post->ID);

            $output .= '<img src="'.dreamy_get_post_thumb($post->ID, $size).'" alt="">';

            if (class_exists('acf') && get_field('post_audio')):

                $field = get_field('post_audio');
                $output .= do_shortcode('[audio src="'.$field.'"]');

            endif;

            $output .= $after;

        endif;


        // Post Gallery
    } elseif($format == 'gallery'){

        if(class_exists('acf')):
            $images = get_field('post_gallery_images');
            $output .= $before;

            if( $images ):
                $output .= '<div class="vl-owl-slider-wrap owl-slider-blog owl-carousel">';

                foreach( $images as $image ):
                    $output .= '<div class="owl-item">';
                    $output .= '<img src="'.$image['sizes'][$size].'" alt="">';
                    $output .= '</div>';
                endforeach;

                $output .= '</div>';
            endif;

            $output .= $after;
        endif;

        // Other posts
    } else {

        if(has_post_thumbnail()):

            $output .= $before;

            // $output .= dreamy_pinterest_share($post->ID);

            if(!is_single()) { $output .= '<a href="'.get_the_permalink($post->ID).'">'; }

            $output .= '<img src="'.dreamy_get_post_thumb($post->ID, $size).'" alt="">';

            if(!is_single()) { $output .= '</a>'; }

            $output .= $after;

        endif;

    }


    return apply_filters('dreamy/post_thumbnail_postformat', $output);
}





/*
 * Post navigation
 * */


function dreamy_post_navigation($before = '', $after = '') {

    global $post;

    $prevPost = get_previous_post();
    $nextPost = get_next_post();

    $output = '';

    if($prevPost || $nextPost):

        $output .= $before;

        $output .= '<div class="row"><div class="col-xs-6">';
        if($prevPost){
            $output .= '<a class="prev" href="'.get_permalink($prevPost->ID).'"><i class="ion ion-chevron-left"></i></a>';
        }
        $output .= '</div>';


        $output .= '<div class="col-xs-6">';

        if($nextPost){
            $output .= '<a class="next" href="'.get_permalink($nextPost->ID).'"><i class="ion ion-chevron-right"></i></a>';
        }

        $output .= '</div></div>';


        $output .= $after;

    endif;

    return apply_filters('dreamy/post_navigation', $output);

}




/*
 * Add thumbnail post to admin
 * */

add_filter('manage_edit-post_columns', 'dreamy_add_thumbnail_column_post', 10, 1);


function dreamy_add_thumbnail_column_post($columns) {

    $column_thumbnail = array(
        'thumbnail' => esc_html__('Thumbnail', 'dreamy'),
    );

    $columns = array_slice($columns, 0, 2, true) + $column_thumbnail + array_slice($columns, 1, NULL, true);

    return $columns;

}



add_action('manage_post_posts_custom_column', 'dreamy_display_thumbnail_post', 10, 1);


function dreamy_display_thumbnail_post($column) {

    global $post;

    switch ($column) {
        case 'thumbnail':

            if(get_the_post_thumbnail($post->ID)){

                echo get_the_post_thumbnail($post->ID, array(50,50));

            }

            break;

    }


}


/*
 * Add admin logo
 * */

add_action('login_head', 'dreamy_change_admin_logo');

function dreamy_change_admin_logo() {
    if ( '' === get_theme_mod( 'login_logo_image', DREAMY_THEME_DIRECTORY . 'assets/img/vlthemes.png' ) ) {
        return;
    }
    $image_url = get_theme_mod( 'login_logo_image', DREAMY_THEME_DIRECTORY . 'assets/img/vlthemes.png' );
    $image_w   = get_theme_mod( 'login_logo_image_width', '102px' );
    $image_h   = get_theme_mod( 'login_logo_image_height', '115px' );
    echo '<style type="text/css">
        h1 a { 
            background: transparent url(' . esc_url( $image_url ) . ') 50% 50% no-repeat !important;
            width:' . esc_attr( $image_w ) . '!important; 
            height:' . esc_attr( $image_h ) . '!important; 
            background-size: cover !important;
        }
    </style>';
}


add_filter('login_headerurl', 'dreamy_change_admin_logo_link');

function dreamy_change_admin_logo_link() {

    return home_url('/');

}


/*
 * page navigation
 * */


function dreamy_page_navigation($query = null, $paginated = false) {

    if($query == null) {
        global $wp_query;
        $query = $wp_query;
    }

    $page = $query->query_vars['paged'];
    $pages = $query->max_num_pages;
    $paged = get_query_var('paged') ? get_query_var('paged') : (get_query_var('page') ? get_query_var('page') : 1);


    if($page == 0) {
        $page = 1;
    }


    $numeric_links = paginate_links(array(
        'foramt' => '',
        'add_args' => '',
        'current' => $paged,
        'total' => $pages,
        'prev_text' => '<i class="ion ion-chevron-left"></i>',
        'next_text' => '<i class="ion ion-chevron-right"></i>',
    ));


    $output = '';


    if($pages > 1) {

        if(false == $paginated) {

            $output .= '<nav class="vl-pagination-buttons clearfix vl-no-select">';

            if ($page + 1 <= $pages) {
                $output .= '<a class="prev-page" href="' . get_pagenum_link($page + 1) . '"><i class="ion ion ion-chevron-left"></i></a>';
            }


            if ($page - 1 >= 1) {
                $output .= '<a class="next-page" href="' . get_pagenum_link($page - 1) . '"><i class="ion ion ion-chevron-right"></i></a>';
            }

            $output .= '</nav>';

        } else {


            $output .= '<nav class="vl-pagination clearfix vl-no-select vl-text-center">';

            $output .= $numeric_links;

            $output .= '</nav>';

        }

    }

    return apply_filters('dreamy/page_navigation', $output);

}




/*
 * Post views
 * */


function dreamy_set_post_views($postID) {

    $count_key = 'dreamy_post_views_count';
    $count = get_post_meta($postID, $count_key, true);

    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}



add_action( 'wp_head', 'dreamy_track_post_views');

function dreamy_track_post_views ($postID) {

    if(!is_single()) return;

    if(empty($postID)){
        global $post;
        $postID = $post->ID;
    }

    dreamy_set_post_views($postID);

}


function dreamy_get_post_views($postID){

    $count_key = 'dreamy_post_views_count';
    $count = get_post_meta($postID, $count_key, true);

    if($count == ''){

        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');

        return '0';
    }

    return $count;
}



