<?php

define('DREAMY_THEME_DIRECTORY', esc_url(trailingslashit(get_template_directory_uri())));
define('DREAMY_REQUIRE_DIRECTORY', trailingslashit(get_template_directory()));
define('DREAMY_DEVELOPMENT', false);

/*
 * After Init
 * */

add_action('after_setup_theme', 'dreamy_theme_setup');
if (!function_exists('dreamy_theme_setup')) {

	function dreamy_theme_setup(){

		load_theme_textdomain('dreamy', DREAMY_THEME_DIRECTORY . 'languages');

		register_nav_menus	(array(
			'primary-menu' => esc_html__('Main Navigation', 'dreamy'),
		));

		add_image_size('dreamy_large_rect_horizontal', 1170, 658, true);
		add_image_size('dreamy_small_thumb', 100,  100, true);
		add_image_size('dreamy_small_square', 560, 560, true);
		add_image_size('dreamy_small_rect_horizontal', 560, 420, true);
		add_image_size('dreamy_small_rect_vertical', 560, 747, true);
		add_image_size('dreamy_medium_square', 900, 900, true);
		add_image_size('dreamy_medium_rect_horizontal', 900, 675, true);
		add_image_size('dreamy_medium_rect_vertical', 840, 1120, true);
		add_image_size('dreamy_fullscreen', 1920, 1920, false);
		add_image_size('dreamy_fullsize', 1920, 1080, false);

		add_theme_support('menus');
		add_theme_support('title-tag');
		add_theme_support('html5', array('comment-list', 'comment-form', 'search-form'));
		add_theme_support('automatic-feed-links');
		add_theme_support('post-thumbnails');
		
		add_theme_support('post-formats', array('gallery', 'video', 'audio', 'link', 'quote'));

	}

}

/*
 * Content width
 * */

add_action('after_setup_theme', 'dreamy_content_width');

function dreamy_content_width() {
    $container_w = get_theme_mod('general_container_width', '960px');
	$GLOBALS['content_width'] = apply_filters('dreamy_content_width', (int)str_replace('px', '', $container_w));
}


/**
 * Add Editor Styles
 */
function dreamy_add_editor_styles() {
	add_editor_style( 'editor-styles.css' );
}
add_action('admin_init', 'dreamy_add_editor_styles');


/*
 * If devmode disabled
 * */

if(!DREAMY_DEVELOPMENT) {
    add_filter('acf/settings/show_admin', '__return_false');
    require_once(DREAMY_REQUIRE_DIRECTORY . 'framework/includes/custom-fields/custom-fields.php');
}

/*
 * Save acf options to json files
 * */

add_filter('acf/settings/save_json', 'dreamy_acf_save_json');

if(!function_exists('dreamy_acf_save_json')) {
	function dreamy_acf_save_json($path) {
	    $path = DREAMY_REQUIRE_DIRECTORY . 'framework/includes/custom-fields';
	    return $path;
	}
}

/*
 * Load acf options from json files
 * */

add_filter('acf/settings/load_json', 'dreamy_acf_load_json');

if(!function_exists('dreamy_acf_load_json')) {
	function dreamy_acf_load_json($paths) {
	    unset($paths[0]);
	    $paths[] = DREAMY_REQUIRE_DIRECTORY . 'framework/includes/custom-fields';
	    return $paths;
	}
}


/*
 * Dashboard
 * */

require_once DREAMY_REQUIRE_DIRECTORY . 'dashboard/dashboard.php';


/*
 * Require Files
 * */

require_once DREAMY_REQUIRE_DIRECTORY . 'framework/includes/vlthemes-includes.php';
require_once DREAMY_REQUIRE_DIRECTORY . 'framework/includes/vlthemes-functions.php';
require_once DREAMY_REQUIRE_DIRECTORY . 'framework/includes/vlthemes-enqueue.php';
require_once DREAMY_REQUIRE_DIRECTORY . 'framework/includes/vlthemes-actions.php';
require_once DREAMY_REQUIRE_DIRECTORY . 'framework/includes/vlthemes-filters.php';
